@@ -6,10 +6,12 @@ from xsdata.codegen.models import AttrType
 from xsdata.models.config import GeneratorConfig
 from xsdata.models.enums import Tag
 from xsdata.utils.namespaces import build_qname
-from xsdata.utils.testing import AttrFactory
-from xsdata.utils.testing import AttrTypeFactory
-from xsdata.utils.testing import ClassFactory
-from xsdata.utils.testing import FactoryTestCase
+from xsdata.utils.testing import (
+    AttrFactory,
+    AttrTypeFactory,
+    ClassFactory,
+    FactoryTestCase,
+)
 
 
 class AddAttributeSubstitutionsTests(FactoryTestCase):
@@ -79,6 +81,11 @@ class AddAttributeSubstitutionsTests(FactoryTestCase):
         self.assertEqual(1, target.attrs[2].restrictions.min_occurs)
         self.assertEqual(0, target.attrs[3].restrictions.min_occurs)
 
+        self.assertEqual("foo", target.attrs[0].substitution)
+        self.assertEqual("foo", target.attrs[1].substitution)
+        self.assertEqual(None, target.attrs[2].substitution)
+        self.assertEqual("foo", target.attrs[3].substitution)
+
         self.processor.process_attribute(target, second_attr)
         self.assertEqual(4, len(target.attrs))
 
