@@ -1,12 +1,8 @@
 import sys
 
 from xsdata.codegen.models import Restrictions
-from xsdata.models.enums import DataType
-from xsdata.models.enums import Namespace
-from xsdata.models.enums import Tag
-from xsdata.utils.testing import AttrFactory
-from xsdata.utils.testing import AttrTypeFactory
-from xsdata.utils.testing import FactoryTestCase
+from xsdata.models.enums import DataType, Namespace, Tag
+from xsdata.utils.testing import AttrFactory, AttrTypeFactory, FactoryTestCase
 
 
 class AttrTests(FactoryTestCase):
@@ -29,6 +25,12 @@ class AttrTests(FactoryTestCase):
         attr.namespace = __file__
         self.assertNotEqual(attr, clone)
 
+    def test_can_be_restricted(self):
+        self.assertFalse(AttrFactory.create(tag=Tag.ATTRIBUTE).can_be_restricted())
+        self.assertFalse(AttrFactory.create(tag=Tag.EXTENSION).can_be_restricted())
+        self.assertFalse(AttrFactory.create(tag=Tag.RESTRICTION).can_be_restricted())
+        self.assertTrue(AttrFactory.create(tag=Tag.ELEMENT).can_be_restricted())
+
     def test_property_key(self):
         attr = AttrFactory.attribute(name="a", namespace="b")
         self.assertEqual("Attribute.b.a", attr.key)
@@ -51,6 +53,18 @@ class AttrTests(FactoryTestCase):
         element.restrictions.max_occurs = 2
         self.assertTrue(element.is_factory)
 
+    def test_property_is_forward_ref(self):
+        attr = AttrFactory.create()
+        self.assertFalse(attr.is_forward_ref)
+
+        attr.types.append(AttrTypeFactory.create("foo", circular=True))
+        self.assertTrue(attr.is_forward_ref)
+
+        attr.types.clear()
+        self.assertFalse(attr.is_forward_ref)
+        attr.types.append(AttrTypeFactory.create("foo", forward=True))
+        self.assertTrue(attr.is_forward_ref)
+
     def test_property_is_group(self):
         self.assertTrue(AttrFactory.group().is_group)
         self.assertTrue(AttrFactory.attribute_group().is_group)
