@@ -2,15 +2,15 @@ import sys
 
 from xsdata.codegen.models import SIMPLE_TYPES
 from xsdata.exceptions import CodeGenerationError
-from xsdata.models.enums import DataType
-from xsdata.models.enums import Namespace
-from xsdata.models.enums import Tag
+from xsdata.models.enums import DataType, Namespace, Tag
 from xsdata.utils.namespaces import build_qname
-from xsdata.utils.testing import AttrFactory
-from xsdata.utils.testing import AttrTypeFactory
-from xsdata.utils.testing import ClassFactory
-from xsdata.utils.testing import ExtensionFactory
-from xsdata.utils.testing import FactoryTestCase
+from xsdata.utils.testing import (
+    AttrFactory,
+    AttrTypeFactory,
+    ClassFactory,
+    ExtensionFactory,
+    FactoryTestCase,
+)
 
 
 class ClassTests(FactoryTestCase):
@@ -144,6 +144,16 @@ class ClassTests(FactoryTestCase):
         obj.attrs.append(AttrFactory.create(tag=Tag.EXTENSION))
         self.assertFalse(obj.is_global_type)
 
+    def test_property_is_restricted(self):
+        obj = ClassFactory.create()
+        ext = ExtensionFactory.create(tag=Tag.EXTENSION)
+        obj.extensions.append(ext)
+
+        self.assertFalse(obj.is_restricted)
+
+        ext.tag = Tag.RESTRICTION
+        self.assertTrue(obj.is_restricted)
+
     def test_property_is_simple_type(self):
         obj = ClassFactory.elements(2)
 
@@ -211,3 +221,26 @@ class ClassTests(FactoryTestCase):
 
         obj = ClassFactory.create(mixed=True)
         self.assertTrue(obj.is_mixed)
+
+    def test_has_forward_ref(self):
+        forward_type = AttrTypeFactory.create("foo", forward=True)
+        circular_type = AttrTypeFactory.create("foo", circular=True)
+
+        obj = ClassFactory.elements(1)
+        self.assertFalse(obj.has_forward_ref())
+
+        obj.attrs[0].types.append(forward_type)
+        self.assertTrue(obj.has_forward_ref())
+
+        obj.attrs[0].types.pop()
+        obj.attrs[0].choices.append(AttrFactory.create())
+        obj.attrs[0].choices.append(AttrFactory.create(types=[circular_type]))
+        self.assertTrue(obj.has_forward_ref())
+
+        obj.attrs.clear()
+        self.assertFalse(obj.has_forward_ref())
+
+        inner = ClassFactory.elements(1)
+        inner.attrs[0].types.append(circular_type)
+        obj.inner.append(inner)
+        self.assertTrue(obj.has_forward_ref())
