@@ -23,6 +23,7 @@ class RestrictionsTests(TestCase):
             explicit_timezone="+1",
             nillable=True,
             path=[("s", 0, 1, 1)],
+            process_contents="skip",
         )
 
     def test_property_is_list(self):
@@ -89,6 +90,7 @@ class RestrictionsTests(TestCase):
             "min_length": 1,
             "nillable": True,
             "pattern": "[A-Z]",
+            "process_contents": "skip",
             "total_digits": 333,
             "white_space": "collapse",
         }
@@ -113,6 +115,7 @@ class RestrictionsTests(TestCase):
             "min_length": 1,
             "nillable": True,
             "pattern": "[A-Z]",
+            "process_contents": "skip",
             "total_digits": 333,
             "white_space": "collapse",
         }
@@ -128,6 +131,13 @@ class RestrictionsTests(TestCase):
         restrictions.max_occurs = sys.maxsize
         self.assertEqual({}, restrictions.asdict())
 
+    def test_asdict_with_process_contents(self):
+        restrictions = Restrictions(process_contents="skip")
+        self.assertEqual({"process_contents": "skip"}, restrictions.asdict())
+
+        restrictions.process_contents = "strict"
+        self.assertEqual({}, restrictions.asdict())
+
     def test_clone(self):
         restrictions = Restrictions(max_occurs=2)
         clone = restrictions.clone()
