@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import List
+from typing import List, Union
 
 
 @dataclass
@@ -12,7 +12,7 @@ class Alpha:
         default=True,
         metadata={
             "type": "Attribute",
-        }
+        },
     )
 
 
@@ -26,7 +26,7 @@ class Bravo:
         default=True,
         metadata={
             "type": "Attribute",
-        }
+        },
     )
 
 
@@ -35,7 +35,7 @@ class Root:
     class Meta:
         name = "root"
 
-    alpha_or_bravo: List[object] = field(
+    alpha_or_bravo: List[Union[Alpha, Bravo]] = field(
         default_factory=list,
         metadata={
             "type": "Elements",
@@ -49,5 +49,5 @@ class Root:
                     "type": Bravo,
                 },
             ),
-        }
+        },
     )
