@@ -11,6 +11,7 @@ class DoubleQuotesDescription:
 
     Dont trip on quotes: "A", "B", "C", "D" My\\Ipsum
     """
+
     class Meta:
         namespace = "urn:docs"
 
@@ -18,28 +19,31 @@ class DoubleQuotesDescription:
 @dataclass
 class DoubleQuotesSummary:
     """Dont trip on quotes: "A", "B", "C", "D" My\\Ipsum"""
+
     class Meta:
         namespace = "urn:docs"
 
 
 class RootEnum(Enum):
     """
-    Attributes
+    Attributes:
         A: Lorem ipsum dolor
         B: Lorem ipsum dolor '''sit''' amet, consectetur adipiscing
             elit. Morbi dapibus. My\\Ipsum
     """
+
     A = "A"
     B = "B"
 
 
 class RootB(Enum):
     """
-    Attributes
+    Attributes:
         YES: This is an inner enum member documentation. Lorem ipsum
             dolor sit amet, consectetur adipiscing elit. Etiam mollis.
         NO: Lorem ipsum dolor My\\Ipsum
     """
+
     YES = "Yes"
     NO = "No"
 
@@ -58,7 +62,7 @@ class Root:
     Donec imperdiet lacus sed sagittis scelerisque. Ut sodales metus:
     "sit", "amet", "lectus" My\\Ipsum
 
-    Attributes
+    Attributes:
         a: This is an inner type '''field''' documentation. Lorem ipsum
             dolor sit amet, consectetur adipiscing elit. Aliquam nec.
             My\\Ipsum
@@ -66,6 +70,7 @@ class Root:
         c:
         d:
     """
+
     class Meta:
         namespace = "urn:docs"
 
@@ -75,7 +80,7 @@ class Root:
             "type": "Element",
             "namespace": "",
             "required": True,
-        }
+        },
     )
     b: Optional[RootB] = field(
         default=None,
@@ -83,7 +88,7 @@ class Root:
             "type": "Element",
             "namespace": "",
             "required": True,
-        }
+        },
     )
     c: Optional[RootEnum] = field(
         default=None,
@@ -91,7 +96,7 @@ class Root:
             "type": "Element",
             "namespace": "",
             "required": True,
-        }
+        },
     )
     d: Optional[RootD] = field(
         default=None,
@@ -99,7 +104,7 @@ class Root:
             "type": "Element",
             "namespace": "",
             "required": True,
-        }
+        },
     )
 
     @dataclass
@@ -107,16 +112,17 @@ class Root:
         """
         This is an inner type documentation.
 
-        Attributes
+        Attributes:
             sub_a: This is an inner type '''field''' documentation.
                 Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                 Vivamus efficitur. My\\Ipsum
         """
+
         sub_a: Optional[str] = field(
             default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
                 "required": True,
-            }
+            },
         )
