@@ -3,35 +3,34 @@ from dataclasses import make_dataclass
 from unittest import mock
 
 from tests.fixtures.books import Books
-from tests.fixtures.models import AttrsType
-from tests.fixtures.models import ExtendedListType
-from tests.fixtures.models import ExtendedType
-from tests.fixtures.models import FixedType
-from tests.fixtures.models import NillableType
-from tests.fixtures.models import Paragraph
-from tests.fixtures.models import SequentialType
-from tests.fixtures.models import TypeA
-from tests.fixtures.models import TypeB
-from tests.fixtures.models import TypeC
+from tests.fixtures.models import (
+    AttrsType,
+    ExtendedListType,
+    ExtendedType,
+    FixedType,
+    NillableType,
+    Paragraph,
+    SequentialType,
+    TypeA,
+    TypeB,
+    TypeC,
+)
 from xsdata.exceptions import ParserError
 from xsdata.formats.dataclass.context import XmlContext
 from xsdata.formats.dataclass.models.elements import XmlType
-from xsdata.formats.dataclass.models.generics import AnyElement
-from xsdata.formats.dataclass.models.generics import DerivedElement
+from xsdata.formats.dataclass.models.generics import AnyElement, DerivedElement
 from xsdata.formats.dataclass.parsers.config import ParserConfig
-from xsdata.formats.dataclass.parsers.nodes import ElementNode
-from xsdata.formats.dataclass.parsers.nodes import PrimitiveNode
-from xsdata.formats.dataclass.parsers.nodes import SkipNode
-from xsdata.formats.dataclass.parsers.nodes import StandardNode
-from xsdata.formats.dataclass.parsers.nodes import UnionNode
-from xsdata.formats.dataclass.parsers.nodes import WildcardNode
+from xsdata.formats.dataclass.parsers.nodes import (
+    ElementNode,
+    PrimitiveNode,
+    SkipNode,
+    StandardNode,
+    UnionNode,
+    WildcardNode,
+)
 from xsdata.formats.dataclass.parsers.utils import ParserUtils
-from xsdata.models.enums import DataType
-from xsdata.models.enums import Namespace
-from xsdata.models.enums import QNames
-from xsdata.utils.testing import FactoryTestCase
-from xsdata.utils.testing import XmlMetaFactory
-from xsdata.utils.testing import XmlVarFactory
+from xsdata.models.enums import DataType, Namespace, QNames
+from xsdata.utils.testing import FactoryTestCase, XmlMetaFactory, XmlVarFactory
 
 
 class ElementNodeTests(FactoryTestCase):
@@ -174,10 +173,10 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual({"wildcard": ["txt", "tail"]}, params)
 
         self.node.bind_wild_text(params, var, None, "tail")
-        self.assertEqual({"wildcard": ["txt", "tail", "tail"]}, params)
+        self.assertEqual({"wildcard": [None, "txt", "tail", "tail"]}, params)
 
         self.node.bind_wild_text(params, var, "first", None)
-        self.assertEqual({"wildcard": ["first", "txt", "tail", "tail"]}, params)
+        self.assertEqual({"wildcard": ["first", None, "txt", "tail", "tail"]}, params)
 
     def test_bind_attrs(self):
         self.node.meta = self.context.build(AttrsType)
@@ -221,6 +220,15 @@ class ElementNodeTests(FactoryTestCase):
 
         self.assertEqual("Unknown attribute ExtendedType:a", str(cm.exception))
 
+    def test_bind_with_fail_on_unknown_attributes_ignores_xsi_attributes(self):
+        self.node.meta = self.context.build(ExtendedType)
+        self.node.config.fail_on_unknown_attributes = True
+        self.node.attrs = {QNames.XSI_TYPE: "b"}
+
+        objects = []
+        self.node.bind("foo", "text", "tail", objects)
+        self.assertEqual(1, len(objects))
+
     @mock.patch("xsdata.formats.dataclass.parsers.nodes.element.logger.warning")
     def test_bind_objects(self, mock_warning):
         self.node.meta = self.context.build(TypeC)
@@ -235,15 +243,16 @@ class ElementNodeTests(FactoryTestCase):
 
     def test_bind_wild_var(self):
         self.node.meta = self.context.build(ExtendedType)
+        x = make_dataclass("x", [("value", int)])
 
         params = {}
-        objects = [("x", 1), ("x", 2), ("z", 3.0)]
+        objects = [("x", x(1)), ("y", 2), ("z", 3.0)]
         self.node.bind_objects(params, objects)
         expected = {
             "wildcard": AnyElement(
                 children=[
-                    AnyElement(qname="x", text="1"),
-                    AnyElement(qname="x", text="2"),
+                    x(1),
+                    AnyElement(qname="y", text="2"),
                     AnyElement(qname="z", text="3.0"),
                 ]
             )
@@ -287,20 +296,8 @@ class ElementNodeTests(FactoryTestCase):
 
         fixture = make_dataclass("Fixture", [("content", str)])
         actual = self.node.prepare_generic_value("a", fixture("foo"), var)
-        expected = DerivedElement(qname="a", value=fixture("foo"), type="Fixture")
-        self.assertEqual(expected, actual)
-
-        fixture = make_dataclass("Fixture", [("content", str)])
-        actual = self.node.prepare_generic_value("known", fixture("foo"), var)
         self.assertEqual(fixture("foo"), actual)
 
-        actual = self.node.prepare_generic_value("a", expected, var)
-        self.assertIs(expected, actual)
-
-        actual = self.node.prepare_generic_value("Fixture", fixture("foo"), var)
-        expected = DerivedElement(qname="Fixture", value=fixture("foo"))
-        self.assertEqual(expected, actual)
-
     def test_child(self):
         var = XmlVarFactory.create(xml_type=XmlType.ELEMENT, qname="a", types=(TypeC,))
         attrs = {"a": "b"}
@@ -316,10 +313,10 @@ class ElementNodeTests(FactoryTestCase):
 
     def test_child_with_unique_element(self):
         single = XmlVarFactory.create(
-            index=1, xml_type=XmlType.ELEMENT, qname="a", types=(TypeC,)
+            index=1, xml_type=XmlType.ELEMENT, qname="cc", types=(TypeC,)
         )
         wildcard = XmlVarFactory.create(
-            index=2, xml_type=XmlType.WILDCARD, qname="a", types=(object,)
+            index=2, xml_type=XmlType.WILDCARD, qname="cc", types=(object,)
         )
         self.meta.elements[single.qname] = [single]
         self.meta.wildcards.append(wildcard)
@@ -328,11 +325,11 @@ class ElementNodeTests(FactoryTestCase):
         ns_map = {"ns0": "xsdata"}
         position = 1
 
-        actual = self.node.child("a", attrs, ns_map, position)
+        actual = self.node.child("cc", attrs, ns_map, position)
         self.assertIsInstance(actual, ElementNode)
         self.assertIn(single.index, self.node.assigned)
 
-        actual = self.node.child("a", attrs, ns_map, position)
+        actual = self.node.child("cc", attrs, ns_map, position)
         self.assertIsInstance(actual, WildcardNode)
         self.assertNotIn(wildcard.index, self.node.assigned)
 
@@ -364,7 +361,7 @@ class ElementNodeTests(FactoryTestCase):
         )
         attrs = {"a": "b"}
         ns_map = {"ns0": "xsdata"}
-        actual = self.node.build_node(var, attrs, ns_map, 10)
+        actual = self.node.build_node(var.qname, var, attrs, ns_map, 10)
 
         self.assertIsInstance(actual, UnionNode)
         self.assertEqual(10, actual.position)
@@ -391,7 +388,7 @@ class ElementNodeTests(FactoryTestCase):
 
         attrs = {"a": "b"}
         ns_map = {"ns0": "xsdata"}
-        actual = self.node.build_node(var, attrs, ns_map, 10)
+        actual = self.node.build_node(var.qname, var, attrs, ns_map, 10)
 
         self.assertIsInstance(actual, ElementNode)
         self.assertEqual(10, actual.position)
@@ -420,7 +417,7 @@ class ElementNodeTests(FactoryTestCase):
 
         attrs = {"a": "b"}
         ns_map = {"ns0": "xsdata"}
-        actual = self.node.build_node(var, attrs, ns_map, 10)
+        actual = self.node.build_node(var.qname, var, attrs, ns_map, 10)
 
         self.assertIsInstance(actual, ElementNode)
         self.assertEqual(10, actual.position)
@@ -439,13 +436,13 @@ class ElementNodeTests(FactoryTestCase):
         mock_ctx_fetch.side_effect = [self.meta, self.meta, nillable_meta]
         attrs = {QNames.XSI_NIL: "false"}
 
-        self.assertIsNotNone(self.node.build_node(var, attrs, ns_map, 10))
+        self.assertIsNotNone(self.node.build_node(var.qname, var, attrs, ns_map, 10))
 
         attrs = {QNames.XSI_NIL: "true"}
-        self.assertIsNotNone(self.node.build_node(var, attrs, ns_map, 10))
+        self.assertIsNone(self.node.build_node(var.qname, var, attrs, ns_map, 10))
 
         attrs = {QNames.XSI_NIL: "false"}
-        self.assertIsNone(self.node.build_node(var, attrs, ns_map, 10))
+        self.assertIsNone(self.node.build_node(var.qname, var, attrs, ns_map, 10))
 
     def test_build_node_with_any_type_var_with_matching_xsi_type(self):
         var = XmlVarFactory.create(
@@ -457,7 +454,7 @@ class ElementNodeTests(FactoryTestCase):
         )
         attrs = {QNames.XSI_TYPE: "bk:books"}
         ns_map = {"bk": "urn:books"}
-        actual = self.node.build_node(var, attrs, ns_map, 10)
+        actual = self.node.build_node(var.qname, var, attrs, ns_map, 10)
 
         self.assertIsInstance(actual, ElementNode)
         self.assertEqual(10, actual.position)
@@ -476,7 +473,7 @@ class ElementNodeTests(FactoryTestCase):
         )
         attrs = {QNames.XSI_TYPE: "xs:hexBinary"}
         ns_map = {Namespace.XS.prefix: Namespace.XS.uri}
-        actual = self.node.build_node(var, attrs, ns_map, 10)
+        actual = self.node.build_node(var.qname, var, attrs, ns_map, 10)
 
         self.assertIsInstance(actual, StandardNode)
         self.assertEqual(ns_map, actual.ns_map)
@@ -487,12 +484,12 @@ class ElementNodeTests(FactoryTestCase):
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
+            qname="aaa",
             types=(object,),
             any_type=True,
         )
         attrs = {QNames.XSI_TYPE: "noMatch"}
-        actual = self.node.build_node(var, attrs, {}, 10)
+        actual = self.node.build_node(var.qname, var, attrs, {}, 10)
 
         self.assertIsInstance(actual, WildcardNode)
         self.assertEqual(10, actual.position)
@@ -504,12 +501,12 @@ class ElementNodeTests(FactoryTestCase):
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
+            qname="aaaa",
             types=(object,),
             any_type=True,
         )
         attrs = {}
-        actual = self.node.build_node(var, attrs, {}, 10)
+        actual = self.node.build_node(var.qname, var, attrs, {}, 10)
 
         self.assertIsInstance(actual, WildcardNode)
         self.assertEqual(10, actual.position)
@@ -517,10 +514,30 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(attrs, actual.attrs)
         self.assertEqual({}, actual.ns_map)
 
-    def test_build_node_with_wildcard_var(self):
-        var = XmlVarFactory.create(xml_type=XmlType.WILDCARD, qname="a")
+    def test_build_node_with_any_type_var_with_no_xsi_type_and_type_exists(self):
+        var = XmlVarFactory.create(
+            xml_type=XmlType.ELEMENT,
+            name="a",
+            qname="a",
+            types=(object,),
+            any_type=True,
+        )
+        attrs = {}
+        a = make_dataclass("a", [("a", int)])
+        actual = self.node.build_node(var.qname, var, attrs, {}, 10)
 
-        actual = self.node.build_node(var, {}, {}, 10)
+        self.assertIsInstance(actual, ElementNode)
+        self.assertEqual(10, actual.position)
+        self.assertEqual(self.context.build(a), actual.meta)
+        self.assertEqual(attrs, actual.attrs)
+        self.assertEqual({}, actual.ns_map)
+        self.assertFalse(actual.mixed)
+
+    def test_build_node_with_wildcard_var(self):
+        var = XmlVarFactory.create(xml_type=XmlType.WILDCARD, qname="aaaaa")
+        var.process_contents = "skip"
+
+        actual = self.node.build_node(var.qname, var, {}, {}, 10)
 
         self.assertIsInstance(actual, WildcardNode)
         self.assertEqual(10, actual.position)
@@ -532,7 +549,7 @@ class ElementNodeTests(FactoryTestCase):
         )
         attrs = {"a": "b"}
         ns_map = {"ns0": "xsdata"}
-        actual = self.node.build_node(var, attrs, ns_map, 10)
+        actual = self.node.build_node(var.qname, var, attrs, ns_map, 10)
 
         self.assertIsInstance(actual, PrimitiveNode)
         self.assertEqual(ns_map, actual.ns_map)
