@@ -1,5 +1,4 @@
-from unittest import mock
-from unittest import TestCase
+from unittest import TestCase, mock
 
 from xsdata.exceptions import XmlContextError
 from xsdata.formats.dataclass.models.elements import XmlType
@@ -58,6 +57,25 @@ class PrimitiveNodeTests(TestCase):
         self.assertTrue(node.bind("foo", None, None, objects))
         self.assertIsNone(objects[-1][1])
 
+    def test_bind_nillable_bytes_content(self):
+        var = XmlVarFactory.create(
+            xml_type=XmlType.TEXT,
+            name="foo",
+            qname="foo",
+            types=(bytes,),
+            nillable=False,
+        )
+        ns_map = {"foo": "bar"}
+        node = PrimitiveNode(var, ns_map, False, DerivedElement)
+        objects = []
+
+        self.assertTrue(node.bind("foo", None, None, objects))
+        self.assertEqual(b"", objects[-1][1])
+
+        var.nillable = True
+        self.assertTrue(node.bind("foo", None, None, objects))
+        self.assertIsNone(objects[-1][1])
+
     def test_bind_mixed_with_tail_content(self):
         var = XmlVarFactory.create(
             xml_type=XmlType.TEXT, name="foo", types=(int,), derived=True
