@@ -1,8 +1,8 @@
 from unittest import TestCase
 
-from tests.fixtures.books import BookForm
-from tests.fixtures.books import Books
+from tests.fixtures.books import BookForm, Books
 from tests.fixtures.books.fixtures import books
+from tests.fixtures.models import Parent
 from xsdata.formats.dataclass.serializers import PycodeSerializer
 from xsdata.models.enums import Namespace
 
@@ -23,22 +23,22 @@ class PycodeSerializerTests(TestCase):
             "books = Books(\n"
             "    book=[\n"
             "        BookForm(\n"
-            '            author="Hightower, Kim",\n'
-            '            title="The First Book",\n'
-            '            genre="Fiction",\n'
+            "            author='Hightower, Kim',\n"
+            "            title='The First Book',\n"
+            "            genre='Fiction',\n"
             "            price=44.95,\n"
             "            pub_date=XmlDate(2000, 10, 1),\n"
-            '            review="An amazing story of nothing.",\n'
-            '            id="bk001"\n'
+            "            review='An amazing story of nothing.',\n"
+            "            id='bk001'\n"
             "        ),\n"
             "        BookForm(\n"
-            '            author="Nagata, Suanne",\n'
-            '            title="Becoming Somebody",\n'
-            '            genre="Biography",\n'
+            "            author='Nagata, Suanne',\n"
+            "            title='Becoming Somebody',\n"
+            "            genre='Biography',\n"
             "            price=33.95,\n"
             "            pub_date=XmlDate(2001, 1, 10),\n"
-            '            review="A masterpiece of the fine art of gossiping.",\n'
-            '            id="bk002"\n'
+            "            review='A masterpiece of the fine art of gossiping.',\n"
+            "            id='bk002'\n"
             "        ),\n"
             "    ]\n"
             ")\n"
@@ -57,7 +57,25 @@ class PycodeSerializerTests(TestCase):
             "books = Books(\n"
             "    book=[\n"
             "        BookForm(\n"
-            '            author="me"\n'
+            "            author='me'\n"
+            "        ),\n"
+            "    ]\n"
+            ")\n"
+        )
+        self.assertEqual(expected, result)
+
+    def test_write_string_with_unicode_characters(self):
+        books = Books(book=[BookForm(author="Backslashes \\ One Two \x12 Three")])
+        result = self.serializer.render(books, var_name="books")
+        expected = (
+            "from tests.fixtures.books.books import BookForm\n"
+            "from tests.fixtures.books.books import Books\n"
+            "\n"
+            "\n"
+            "books = Books(\n"
+            "    book=[\n"
+            "        BookForm(\n"
+            "            author='Backslashes \\\\ One Two \\x12 Three'\n"
             "        ),\n"
             "    ]\n"
             ")\n"
@@ -79,15 +97,13 @@ class PycodeSerializerTests(TestCase):
         self.assertEqual("{}", "".join(iterator))
 
         iterator = self.serializer.write_object({"foo": "bar"}, 0, set())
-        self.assertEqual('{\n    "foo": "bar",\n}', "".join(iterator))
+        self.assertEqual("{\n    'foo': 'bar',\n}", "".join(iterator))
 
     def test_write_object_with_enum(self):
         iterator = self.serializer.write_object(Namespace.SOAP11, 0, set())
         self.assertEqual("Namespace.SOAP11", "".join(iterator))
 
-    def test_build_imports_ignores_nested_types(self):
-        class Foo:
-            pass
-
-        actual = self.serializer.build_imports({Foo})
-        self.assertEqual("", actual)
+    def test_build_imports_with_nested_types(self):
+        expected = "from tests.fixtures.models import Parent\n"
+        actual = self.serializer.build_imports({Parent.Inner})
+        self.assertEqual(expected, actual)
