@@ -1,16 +1,12 @@
 import json
 import warnings
 from unittest.case import TestCase
-from unittest.mock import ANY
-from unittest.mock import call
-from unittest.mock import Mock
+from unittest.mock import ANY, Mock, call
 
-from tests.fixtures.books import BookForm
-from tests.fixtures.books import Books
+from tests.fixtures.books import BookForm, Books
 from tests.fixtures.datatypes import Telephone
 from xsdata.exceptions import XmlContextError
-from xsdata.formats.dataclass.serializers.json import DictFactory
-from xsdata.formats.dataclass.serializers.json import JsonSerializer
+from xsdata.formats.dataclass.serializers.json import DictFactory, JsonSerializer
 from xsdata.models.datatype import XmlDate
 from xsdata.models.xsd import Attribute
 from xsdata.utils.testing import XmlVarFactory
