@@ -4,21 +4,23 @@ from unittest import mock
 from tests.fixtures.datatypes import Telephone
 from xsdata.codegen.models import Restrictions
 from xsdata.formats.dataclass.filters import Filters
-from xsdata.models.config import DocstringStyle
-from xsdata.models.config import ExtensionType
-from xsdata.models.config import GeneratorConfig
-from xsdata.models.config import GeneratorExtension
-from xsdata.models.config import GeneratorSubstitution
-from xsdata.models.config import NameCase
-from xsdata.models.config import ObjectType
-from xsdata.models.enums import DataType
-from xsdata.models.enums import Namespace
-from xsdata.models.enums import Tag
-from xsdata.utils.testing import AttrFactory
-from xsdata.utils.testing import AttrTypeFactory
-from xsdata.utils.testing import ClassFactory
-from xsdata.utils.testing import ExtensionFactory
-from xsdata.utils.testing import FactoryTestCase
+from xsdata.models.config import (
+    DocstringStyle,
+    ExtensionType,
+    GeneratorConfig,
+    GeneratorExtension,
+    GeneratorSubstitution,
+    NameCase,
+    ObjectType,
+)
+from xsdata.models.enums import DataType, Namespace, Tag
+from xsdata.utils.testing import (
+    AttrFactory,
+    AttrTypeFactory,
+    ClassFactory,
+    ExtensionFactory,
+    FactoryTestCase,
+)
 
 type_str = AttrTypeFactory.native(DataType.STRING)
 type_int = AttrTypeFactory.native(DataType.INT)
@@ -142,6 +144,10 @@ class FiltersTests(FactoryTestCase):
         expected = self.filters.class_annotations(target, "FooBar")
         self.assertEqual(["@c", "@b", "@dataclass", "@d"], expected)
 
+        self.filters.default_class_annotation = None
+        expected = self.filters.class_annotations(target, "FooBar")
+        self.assertEqual(["@c", "@b", "@d"], expected)
+
     def test_field_name(self):
         self.filters.substitutions[ObjectType.FIELD]["abc"] = "cba"
 
@@ -155,6 +161,9 @@ class FiltersTests(FactoryTestCase):
         self.assertEqual("value_minus_1_1", self.filters.field_name("-1.1", "cls"))
         self.assertEqual("cbad", self.filters.field_name("abcd", "cls"))
 
+        self.filters.field_case = NameCase.ORIGINAL
+        self.assertEqual("foo", self.filters.field_name("@foo", "cls"))
+
     def test_constant_name(self):
         self.filters.substitutions[ObjectType.FIELD]["ABC"] = "CBA"
 
@@ -281,6 +290,14 @@ class FiltersTests(FactoryTestCase):
         )
         self.assertEqual(expected, result)
 
+    @mock.patch.object(Filters, "field_metadata")
+    def test_field_definition_without_metadata(self, mock_field_metadata):
+        mock_field_metadata.return_value = {}
+        str_attr = AttrFactory.create(types=[type_str], tag=Tag.RESTRICTION)
+        result = self.filters.field_definition(str_attr, {}, None, ["Root"])
+        expected = "field(\n" "        default=None\n" "    )"
+        self.assertEqual(expected, result)
+
     def test_field_default_value_with_value_none(self):
         attr = AttrFactory.create(types=[type_str])
         self.assertEqual(None, self.filters.field_default_value(attr))
@@ -293,7 +310,7 @@ class FiltersTests(FactoryTestCase):
 
     def test_field_default_value_with_type_str(self):
         attr = AttrFactory.create(types=[type_str], default="foo")
-        self.assertEqual('"foo"', self.filters.field_default_value(attr))
+        self.assertEqual("'foo'", self.filters.field_default_value(attr))
 
     def test_field_default_value_with_type_tokens(self):
         attr = AttrFactory.create(types=[type_int, type_str], default="1  \n bar")
@@ -335,13 +352,13 @@ class FiltersTests(FactoryTestCase):
 
     def test_field_default_value_with_type_decimal(self):
         attr = AttrFactory.create(types=[type_decimal], default="1.5")
-        self.assertEqual('Decimal("1.5")', self.filters.field_default_value(attr))
+        self.assertEqual("Decimal('1.5')", self.filters.field_default_value(attr))
 
         attr.default = "-inf"
-        self.assertEqual('Decimal("-Infinity")', self.filters.field_default_value(attr))
+        self.assertEqual("Decimal('-Infinity')", self.filters.field_default_value(attr))
 
         attr.default = "inf"
-        self.assertEqual('Decimal("Infinity")', self.filters.field_default_value(attr))
+        self.assertEqual("Decimal('Infinity')", self.filters.field_default_value(attr))
 
     def test_field_default_value_with_type_int(self):
         attr = AttrFactory.create(types=[type_int], default="1")
@@ -371,7 +388,7 @@ class FiltersTests(FactoryTestCase):
         self.assertEqual(expected, self.filters.field_default_value(attr))
 
         attr.types[0].qname = "nomatch"  # impossible
-        with self.assertRaises(Exception):
+        with self.assertRaises(StopIteration):
             self.filters.field_default_value(attr)
 
     def test_field_default_value_with_type_qname(self):
@@ -513,7 +530,7 @@ class FiltersTests(FactoryTestCase):
                 "wildcard": True,
                 "type": "Type[object]",
             },
-            {"default": '"aa"', "name": "bar", "type": "Type[str]"},
+            {"default": "'aa'", "name": "bar", "type": "Type[str]"},
             {
                 "default_factory": "list",
                 "name": "tok",
@@ -734,7 +751,7 @@ class FiltersTests(FactoryTestCase):
 
         self.filters.postponed_annotations = True
         actual = self.filters.choice_type(choice, ["a", "b"])
-        self.assertEqual("Type[Foobar]", actual)
+        self.assertEqual('Type["Foobar"]', actual)
 
     def test_choice_type_with_multiple_types(self):
         choice = AttrFactory.create(types=[type_str, type_bool])
@@ -877,29 +894,39 @@ class FiltersTests(FactoryTestCase):
         self.assertEqual(expected, self.filters.default_imports(output))
 
     def test_default_imports_with_annotations(self):
-        config = GeneratorConfig()
-        config.output.postponed_annotations = True
-        filters = Filters(config)
+        self.filters.postponed_annotations = True
 
         expected = "from __future__ import annotations"
-        self.assertEqual(expected, filters.default_imports(""))
+        self.assertEqual(expected, self.filters.default_imports(""))
+
+    def test_default_imports_ordering(self):
+        self.filters.postponed_annotations = True
+        self.filters.import_patterns["attrs"] = {"__module__": ["@attrs.s"]}
+
+        expected = (
+            "from __future__ import annotations\n"
+            "import attrs\n"
+            "from dataclasses import dataclass"
+        )
+        self.assertEqual(expected, self.filters.default_imports("@dataclass @attrs.s"))
 
     def test_format_metadata(self):
-        data = dict(
-            num=1,
-            text="foo",
-            text_two="fo'o",
-            text_three='fo"o',
-            pattern="foo",
-            custom=Telephone(30, 123, 4567),
-            level_two=dict(a=1),
-            list=[
-                dict(type="Type[object]"),
-                dict(type="Type[object] mpla"),
+        data = {
+            "num": 1,
+            "text": "foo",
+            "text_two": "fo'o",
+            "text_three": 'fo"o',
+            "pattern": "foo",
+            "custom": Telephone(30, 123, 4567),
+            "level_two": {"a": 1},
+            "list": [
+                {"type": "Type[object]"},
+                {"type": 'type["something"]'},
+                {"type": "Type[object] mpla"},
             ],
-            default="1",
-            default_factory="list",
-        )
+            "default": "1",
+            "default_factory": "list",
+        }
 
         expected = (
             "{\n"
@@ -917,6 +944,9 @@ class FiltersTests(FactoryTestCase):
             '            "type": object,\n'
             "        },\n"
             "        {\n"
+            '            "type": type["something"],\n'
+            "        },\n"
+            "        {\n"
             '            "type": "Type[object] mpla",\n'
             "        },\n"
             "    ],\n"
