@@ -3,8 +3,7 @@ import os
 import pytest
 from click.testing import CliRunner
 
-from tests import fixtures_dir
-from tests import root
+from tests import fixtures_dir, root
 from xsdata.cli import cli
 from xsdata.formats.dataclass.context import XmlContext
 from xsdata.formats.dataclass.parsers.xml import XmlParser
