@@ -2,8 +2,7 @@ import os
 
 from click.testing import CliRunner
 
-from tests import fixtures_dir
-from tests import root
+from tests import fixtures_dir, root
 from xsdata.cli import cli
 from xsdata.utils.testing import load_class
 
@@ -30,5 +29,5 @@ def test_books_schema():
         raise result.exception
 
     clazz = load_class(result.output, "Books")
-    assert "books" == clazz.Meta.name
-    assert "urn:books" == clazz.Meta.namespace
+    assert clazz.Meta.name == "books"
+    assert clazz.Meta.namespace == "urn:books"
