@@ -2,8 +2,7 @@ import os
 
 from click.testing import CliRunner
 
-from tests import fixtures_dir
-from tests import root
+from tests import fixtures_dir, root
 from tests.conftest import validate_bindings
 from xsdata.cli import cli
 from xsdata.utils.testing import load_class
