@@ -2,8 +2,7 @@ import os
 
 from click.testing import CliRunner
 
-from tests import fixtures_dir
-from tests import root
+from tests import fixtures_dir, root
 from xsdata.cli import cli
 
 os.chdir(root)
