@@ -5,16 +5,17 @@ from pathlib import Path
 from unittest import TestCase
 
 from xsdata import __version__
-from xsdata.exceptions import GeneratorConfigError
-from xsdata.exceptions import ParserError
-from xsdata.models.config import ExtensionType
-from xsdata.models.config import GeneratorAlias
-from xsdata.models.config import GeneratorAliases
-from xsdata.models.config import GeneratorConfig
-from xsdata.models.config import GeneratorExtension
-from xsdata.models.config import GeneratorOutput
-from xsdata.models.config import ObjectType
-from xsdata.models.config import OutputFormat
+from xsdata.exceptions import GeneratorConfigError, ParserError
+from xsdata.models.config import (
+    ExtensionType,
+    GeneratorAlias,
+    GeneratorAliases,
+    GeneratorConfig,
+    GeneratorExtension,
+    GeneratorOutput,
+    ObjectType,
+    OutputFormat,
+)
 
 
 class GeneratorConfigTests(TestCase):
@@ -37,7 +38,7 @@ class GeneratorConfigTests(TestCase):
             "    <DocstringStyle>reStructuredText</DocstringStyle>\n"
             "    <FilterStrategy>allGlobals</FilterStrategy>\n"
             "    <RelativeImports>false</RelativeImports>\n"
-            '    <CompoundFields defaultName="choice" forceDefaultName="false">false</CompoundFields>\n'
+            '    <CompoundFields defaultName="choice" useSubstitutionGroups="false" forceDefaultName="false" maxNameParts="3">false</CompoundFields>\n'
             "    <PostponedAnnotations>false</PostponedAnnotations>\n"
             "    <UnnestClasses>false</UnnestClasses>\n"
             "    <IgnorePatterns>false</IgnorePatterns>\n"
@@ -99,7 +100,7 @@ class GeneratorConfigTests(TestCase):
             "    <DocstringStyle>reStructuredText</DocstringStyle>\n"
             "    <FilterStrategy>allGlobals</FilterStrategy>\n"
             "    <RelativeImports>false</RelativeImports>\n"
-            '    <CompoundFields defaultName="choice" forceDefaultName="false">false</CompoundFields>\n'
+            '    <CompoundFields defaultName="choice" useSubstitutionGroups="false" forceDefaultName="false" maxNameParts="3">false</CompoundFields>\n'
             "    <PostponedAnnotations>false</PostponedAnnotations>\n"
             "    <UnnestClasses>false</UnnestClasses>\n"
             "    <IgnorePatterns>false</IgnorePatterns>\n"
@@ -122,7 +123,7 @@ class GeneratorConfigTests(TestCase):
     def test_read_with_wrong_value(self):
         existing = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
-            f'<Config xmlns="http://pypi.org/project/xsdata" version="21.7">\n'
+            '<Config xmlns="http://pypi.org/project/xsdata" version="21.7">\n'
             '  <Output maxLineLength="79">\n'
             "    <Structure>unknown</Structure>\n"
             "  </Output>\n"
@@ -156,7 +157,7 @@ class GeneratorConfigTests(TestCase):
                 GeneratorOutput(subscriptable_types=True).subscriptable_types
             )
 
-    def test_use_union_type_requires_310(self):
+    def test_use_union_type_requires_310_and_postponed_annotations(self):
         if sys.version_info < (3, 10):
             with warnings.catch_warnings(record=True) as w:
                 self.assertFalse(GeneratorOutput(union_type=True).union_type)
@@ -165,9 +166,15 @@ class GeneratorConfigTests(TestCase):
                 "UnionType PEP 604 requires python >= 3.10, reverting...",
                 str(w[-1].message),
             )
-
         else:
-            self.assertTrue(GeneratorOutput(union_type=True).union_type)
+            with warnings.catch_warnings(record=True) as w:
+                output = GeneratorOutput(union_type=True)
+                self.assertTrue(output.postponed_annotations)
+
+                self.assertEqual(
+                    "Enabling postponed annotations, because `union_type==True`",
+                    str(w[-1].message),
+                )
 
     def test_format_slots_requires_310(self):
         if sys.version_info < (3, 10):
@@ -197,27 +204,6 @@ class GeneratorConfigTests(TestCase):
         else:
             self.assertIsNotNone(OutputFormat(kw_only=True))
 
-    def test_postponed_annotations_requires_37(self):
-        # We need to confuse pyupgrade into not discarding Python version checks,
-        # which are needed to know when the warning is triggered or not
-        # Extracting the version in a local variable before performing the check is
-        # sufficient for that purpose.
-        v = sys.version_info
-        if v < (3, 7):
-            with warnings.catch_warnings(record=True) as w:
-                self.assertFalse(
-                    GeneratorOutput(postponed_annotations=True).postponed_annotations
-                )
-                self.assertEqual(
-                    "postponed annotations requires python >= 3.7, reverting...",
-                    str(w[-1].message),
-                )
-
-        if v >= (3, 7):
-            self.assertTrue(
-                GeneratorOutput(postponed_annotations=True).postponed_annotations
-            )
-
     def test_init_config_with_aliases(self):
         config = GeneratorConfig(
             aliases=GeneratorAliases(
@@ -258,4 +244,4 @@ class GeneratorConfigTests(TestCase):
                 type=ExtensionType.DECORATOR, import_string="a.b", class_name="*Foo"
             )
 
-        self.assertEqual(f"Failed to compile pattern '*Foo'", str(cm.exception))
+        self.assertEqual("Failed to compile pattern '*Foo'", str(cm.exception))
