@@ -1,16 +1,8 @@
-from datetime import date
-from datetime import datetime
-from datetime import time
-from datetime import timedelta
-from datetime import timezone
+from datetime import date, datetime, time, timedelta, timezone
 from typing import Dict
 from unittest import TestCase
 
-from xsdata.models.datatype import XmlDate
-from xsdata.models.datatype import XmlDateTime
-from xsdata.models.datatype import XmlDuration
-from xsdata.models.datatype import XmlPeriod
-from xsdata.models.datatype import XmlTime
+from xsdata.models.datatype import XmlDate, XmlDateTime, XmlDuration, XmlPeriod, XmlTime
 
 
 def filter_none(mapping: Dict) -> Dict:
@@ -226,7 +218,7 @@ class XmlDateTimeTests(TestCase):
             XmlDateTime.utcnow().replace(fractional_second=0, second=0, minute=1),
         )
 
-        now = datetime.utcnow().replace(microsecond=0, second=0, minute=1)
+        now = datetime.now(timezone.utc).replace(microsecond=0, second=0, minute=1)
         self.assertEqual(
             XmlDateTime.from_datetime(now),
             XmlDateTime.utcnow().replace(fractional_second=0, second=0, minute=1),
@@ -372,7 +364,7 @@ class XmlTimeTests(TestCase):
             XmlTime.utcnow().replace(fractional_second=0, second=0, minute=1),
         )
 
-        now = datetime.utcnow().replace(microsecond=0, second=0, minute=1)
+        now = datetime.now(timezone.utc).replace(microsecond=0, second=0, minute=1)
         self.assertEqual(
             XmlTime.from_time(now.time()),
             XmlTime.utcnow().replace(fractional_second=0, second=0, minute=1),
