@@ -1,13 +1,8 @@
 from collections import defaultdict
-from typing import Dict
-from typing import List
-from typing import Optional
+from typing import Dict, List, Optional
 
-from xsdata.codegen.mixins import ContainerInterface
-from xsdata.codegen.mixins import RelativeHandlerInterface
-from xsdata.codegen.models import Attr
-from xsdata.codegen.models import AttrType
-from xsdata.codegen.models import Class
+from xsdata.codegen.mixins import ContainerInterface, RelativeHandlerInterface
+from xsdata.codegen.models import Attr, AttrType, Class
 from xsdata.codegen.utils import ClassUtils
 from xsdata.models.enums import Tag
 from xsdata.utils import collections
@@ -39,9 +34,9 @@ class AddAttributeSubstitutions(RelativeHandlerInterface):
     def process_attribute(self, target: Class, attr: Attr):
         """
         Check if the given attribute matches any substitution class in order to
-        clone it's attributes to the target class.
+        clone its attributes to the target class.
 
-        The cloned attributes are placed below the attribute the are
+        The cloned attributes are placed below the attribute they are
         supposed to substitute.
 
         Guard against multiple substitutions in case of xs:groups.
@@ -61,6 +56,8 @@ class AddAttributeSubstitutions(RelativeHandlerInterface):
                 clone.restrictions.min_occurs = 0
                 clone.restrictions.max_occurs = attr.restrictions.max_occurs
 
+                attr.substitution = clone.substitution = attr_type.name
+
                 pos = collections.find(target.attrs, clone)
                 index = pos + 1 if pos > -1 else index
                 target.attrs.insert(index, clone)
