@@ -1,20 +1,12 @@
 from collections import Counter
-from typing import Dict
-from typing import List
-from typing import Set
-from typing import Tuple
+from typing import Dict, List, Set, Tuple
 
-from xsdata.codegen.mixins import ContainerInterface
-from xsdata.codegen.mixins import RelativeHandlerInterface
-from xsdata.codegen.models import Attr
-from xsdata.codegen.models import AttrType
-from xsdata.codegen.models import Class
-from xsdata.codegen.models import get_restriction_choice
-from xsdata.codegen.models import Restrictions
+from xsdata.codegen.mixins import ContainerInterface, RelativeHandlerInterface
+from xsdata.codegen.models import Attr, Class, Restrictions, get_restriction_choice
 from xsdata.codegen.utils import ClassUtils
 from xsdata.formats.dataclass.models.elements import XmlType
-from xsdata.models.enums import DataType
 from xsdata.models.enums import Tag
+from xsdata.utils import collections
 from xsdata.utils.collections import group_by
 
 ALL = "a"
@@ -79,25 +71,28 @@ class CreateCompoundFields(RelativeHandlerInterface):
         assert choice is not None
 
         names = []
+        substitutions = []
         choices = []
         counters: Dict = {"min": [], "max": []}
 
         for attr in attrs:
             ClassUtils.remove_attribute(target, attr)
             names.append(attr.local_name)
-            choices.append(self.build_attr_choice(attr))
+            substitutions.append(attr.substitution)
 
+            choices.append(self.build_attr_choice(attr))
             self.update_counters(attr, counters)
 
         min_occurs, max_occurs = self.sum_counters(counters)
-        name = self.choose_name(target, names)
+        name = self.choose_name(target, names, list(filter(None, substitutions)))
+        types = collections.unique_sequence(t for attr in attrs for t in attr.types)
 
         target.attrs.insert(
             pos,
             Attr(
                 name=name,
                 index=0,
-                types=[AttrType(qname=str(DataType.ANY_TYPE), native=True)],
+                types=types,
                 tag=Tag.CHOICE,
                 restrictions=Restrictions(
                     min_occurs=sum(min_occurs),
@@ -123,12 +118,14 @@ class CreateCompoundFields(RelativeHandlerInterface):
 
         return min_occurs, max_occurs
 
-    def choose_name(self, target: Class, names: List[str]) -> str:
-        if (
-            self.config.force_default_name
-            or len(names) > 3
-            or len(names) != len(set(names))
-        ):
+    def choose_name(
+        self, target: Class, names: List[str], substitutions: List[str]
+    ) -> str:
+        if self.config.use_substitution_groups and len(names) == len(substitutions):
+            names = substitutions
+
+        names = collections.unique_sequence(names)
+        if self.config.force_default_name or len(names) > self.config.max_name_parts:
             name = self.config.default_name
         else:
             name = "_Or_".join(names)
