@@ -1,8 +1,7 @@
 from typing import List
 
 from xsdata.codegen.mixins import HandlerInterface
-from xsdata.codegen.models import Attr
-from xsdata.codegen.models import Class
+from xsdata.codegen.models import Attr, Class
 from xsdata.codegen.utils import ClassUtils
 from xsdata.utils import collections
 
