@@ -1,13 +1,8 @@
 import sys
 
 from xsdata.codegen.mixins import HandlerInterface
-from xsdata.codegen.models import Attr
-from xsdata.codegen.models import AttrType
-from xsdata.codegen.models import Class
-from xsdata.codegen.models import Restrictions
-from xsdata.models.enums import DataType
-from xsdata.models.enums import NamespaceType
-from xsdata.models.enums import Tag
+from xsdata.codegen.models import Attr, AttrType, Class, Restrictions
+from xsdata.models.enums import DataType, NamespaceType, Tag
 
 
 class ProcessMixedContentClass(HandlerInterface):
@@ -31,7 +26,7 @@ class ProcessMixedContentClass(HandlerInterface):
         for attr in list(target.attrs):
             if attr.is_attribute:
                 attrs.append(attr)
-            elif attr.tag != Tag.ANY:
+            elif not attr.is_any_type:
                 choice = attr.clone()
                 choice.restrictions.min_occurs = None
                 choice.restrictions.max_occurs = None
