@@ -1,12 +1,8 @@
 import abc
 from abc import ABCMeta
-from typing import Callable
-from typing import Iterator
-from typing import List
-from typing import Optional
+from typing import Callable, Iterator, List, Optional
 
-from xsdata.codegen.models import Attr
-from xsdata.codegen.models import Class
+from xsdata.codegen.models import Attr, Class
 from xsdata.models.config import GeneratorConfig
 from xsdata.utils.constants import return_true
 
@@ -82,7 +78,10 @@ class RelativeHandlerInterface(HandlerInterface, metaclass=ABCMeta):
             assert base is not None
 
             attrs.extend(self.base_attrs(base))
-            attrs.extend(base.attrs)
+
+            for attr in base.attrs:
+                attr.parent = base
+                attrs.append(attr)
 
         return attrs
 
