@@ -1,27 +1,15 @@
 import operator
 import sys
-from dataclasses import asdict
-from dataclasses import dataclass
-from dataclasses import field
-from dataclasses import replace
+from dataclasses import asdict, dataclass, field, replace
 from enum import IntEnum
-from typing import Any
-from typing import Dict
-from typing import Iterator
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import Type
+from typing import Any, Dict, Iterator, List, Optional, Tuple, Type
 
 from xsdata.exceptions import CodeGenerationError
 from xsdata.formats.converter import converter
 from xsdata.formats.dataclass.models.elements import XmlType
-from xsdata.models.enums import DataType
-from xsdata.models.enums import Namespace
-from xsdata.models.enums import Tag
+from xsdata.models.enums import DataType, Namespace, Tag
 from xsdata.models.mixins import ElementBase
-from xsdata.utils import namespaces
-from xsdata.utils import text
+from xsdata.utils import namespaces, text
 
 xml_type_map = {
     Tag.ANY: XmlType.WILDCARD,
@@ -37,29 +25,8 @@ GLOBAL_TYPES = (Tag.ELEMENT, Tag.BINDING_OPERATION, Tag.BINDING_MESSAGE, Tag.MES
 
 @dataclass
 class Restrictions:
-    """
-    Model representation of a dataclass field validation and type metadata.
-
-    :param min_occurs:
-    :param max_occurs:
-    :param min_exclusive:
-    :param min_inclusive:
-    :param min_length:
-    :param max_exclusive:
-    :param max_inclusive:
-    :param max_length:
-    :param total_digits:
-    :param fraction_digits:
-    :param length:
-    :param white_space:
-    :param pattern:
-    :param explicit_timezone:
-    :param nillable:
-    :param sequence:
-    :param tokens:
-    :param format:
-    :param choice:
-    """
+    """Model representation of a dataclass field validation and type
+    metadata."""
 
     min_occurs: Optional[int] = field(default=None)
     max_occurs: Optional[int] = field(default=None)
@@ -81,6 +48,7 @@ class Restrictions:
     format: Optional[str] = field(default=None)
     choice: Optional[int] = field(default=None)
     group: Optional[int] = field(default=None)
+    process_contents: Optional[str] = field(default=None)
     path: List[Tuple[str, int, int, int]] = field(default_factory=list)
 
     @property
@@ -128,6 +96,7 @@ class Restrictions:
             "white_space",
             "pattern",
             "explicit_timezone",
+            "process_contents",
         )
 
         for key in keys:
@@ -163,6 +132,9 @@ class Restrictions:
             ):
                 continue
 
+            if key == "process_contents" and value != "skip":
+                continue
+
             if key.endswith("clusive") and types:
                 value = converter.deserialize(value, sorted_types)
 
@@ -176,7 +148,7 @@ class Restrictions:
 
     @classmethod
     def from_element(cls, element: ElementBase) -> "Restrictions":
-        """Static constructor from an xsd model."""
+        """Static constructor from a xsd model."""
         return cls(**element.get_restrictions())
 
 
@@ -188,17 +160,8 @@ class AttrCategory(IntEnum):
 
 @dataclass(unsafe_hash=True)
 class AttrType:
-    """
-    Model representation for the typing information for fields and extensions.
-
-    :param qname:
-    :param alias:
-    :param reference:
-    :param native:
-    :param forward:
-    :param circular:
-    :param substituted:
-    """
+    """Model representation for the typing information for fields and
+    extensions."""
 
     qname: str
     alias: Optional[str] = field(default=None, compare=False)
@@ -218,7 +181,7 @@ class AttrType:
         return namespaces.local_name(self.qname)
 
     def is_dependency(self, allow_circular: bool) -> bool:
-        """Return true if attribute is not a forward/circular references and
+        """Return true if attribute is not a forward/circular references, and
         it's not a native python time."""
 
         return not (
@@ -232,22 +195,7 @@ class AttrType:
 
 @dataclass
 class Attr:
-    """
-    Model representation for a dataclass field.
-
-    :param tag:
-    :param name:
-    :param local_name:
-    :param index:
-    :param default:
-    :param fixed:
-    :param mixed:
-    :param types:
-    :param choices:
-    :param namespace:
-    :param help:
-    :param restrictions:
-    """
+    """Model representation for a dataclass field."""
 
     tag: str
     name: str = field(compare=False)
@@ -261,6 +209,8 @@ class Attr:
     namespace: Optional[str] = field(default=None)
     help: Optional[str] = field(default=None, compare=False)
     restrictions: Restrictions = field(default_factory=Restrictions, compare=False)
+    parent: Optional["Class"] = field(default=None, compare=False)
+    substitution: Optional[str] = field(default=None, compare=False)
 
     def __post_init__(self):
         self.local_name = self.name
@@ -271,13 +221,13 @@ class Attr:
 
     @property
     def is_attribute(self) -> bool:
-        """Return whether this attribute is derived from an xs:attribute or
+        """Return whether this attribute is derived from a xs:attribute or
         xs:anyAttribute."""
         return self.tag in (Tag.ATTRIBUTE, Tag.ANY_ATTRIBUTE)
 
     @property
     def is_enumeration(self) -> bool:
-        """Return whether this attribute is derived from an xs:enumeration."""
+        """Return whether this attribute is derived from a xs:enumeration."""
         return self.tag == Tag.ENUMERATION
 
     @property
@@ -290,9 +240,13 @@ class Attr:
         """Return whether this attribute is a list of items or a mapping."""
         return self.is_list or self.is_dict or self.is_tokens
 
+    @property
+    def is_forward_ref(self) -> bool:
+        return any(tp.circular or tp.forward for tp in self.types)
+
     @property
     def is_group(self) -> bool:
-        """Return whether this attribute is derived from an xs:group or
+        """Return whether this attribute is derived from a xs:group or
         xs:attributeGroup."""
         return self.tag in (Tag.ATTRIBUTE_GROUP, Tag.GROUP)
 
@@ -323,7 +277,7 @@ class Attr:
 
     @property
     def is_suffix(self) -> bool:
-        """Return whether this attribute is not derived from an xs element with
+        """Return whether this attribute is not derived from a xs element with
         mode suffix."""
         return self.index == sys.maxsize
 
@@ -383,16 +337,14 @@ class Attr:
             if datatype:
                 yield datatype.type
 
+    def can_be_restricted(self) -> bool:
+        """Return whether this attribute can be restricted."""
+        return self.xml_type not in (Tag.ATTRIBUTE, None)
+
 
 @dataclass(unsafe_hash=True)
 class Extension:
-    """
-    Model representation of a dataclass base class.
-
-    :param tag:
-    :param type:
-    :param restrictions:
-    """
+    """Model representation of a dataclass base class."""
 
     tag: str
     type: AttrType
@@ -423,32 +375,8 @@ class Status(IntEnum):
 
 @dataclass
 class Class:
-    """
-    Model representation of a dataclass with fields, base/inner classes and
-    additional metadata settings.
-
-    :param qname:
-    :param tag:
-    :param location:
-    :param mixed:
-    :param abstract:
-    :param nillable:
-    :param local_type:
-    :param status:
-    :param container:
-    :param package:
-    :param module:
-    :param namespace:
-    :param help:
-    :param meta_name:
-    :param default:
-    :param fixed:
-    :param substitutions:
-    :param extensions:
-    :param attrs:
-    :param inner:
-    :param ns_map:
-    """
+    """Model representation of a dataclass with fields, base/inner classes and
+    additional metadata settings."""
 
     qname: str
     tag: str
@@ -501,13 +429,13 @@ class Class:
 
     @property
     def is_complex(self) -> bool:
-        """Return whether this instance is derived from an xs:element or
+        """Return whether this instance is derived from a xs:element or
         xs:complexType."""
         return self.tag in (Tag.ELEMENT, Tag.COMPLEX_TYPE)
 
     @property
     def is_element(self) -> bool:
-        """Return whether this instance is derived from an non abstract
+        """Return whether this instance is derived from a non abstract
         xs:element."""
         return self.tag == Tag.ELEMENT
 
@@ -526,7 +454,7 @@ class Class:
 
     @property
     def is_group(self) -> bool:
-        """Return whether this attribute is derived from an xs:group or
+        """Return whether this attribute is derived from a xs:group or
         xs:attributeGroup."""
         return self.tag in (Tag.ATTRIBUTE_GROUP, Tag.GROUP)
 
@@ -540,6 +468,12 @@ class Class:
         """Return whether this class supports mixed content."""
         return self.mixed or any(x.mixed for x in self.attrs)
 
+    @property
+    def is_restricted(self) -> bool:
+        return any(
+            True for extension in self.extensions if extension.tag == Tag.RESTRICTION
+        )
+
     @property
     def is_service(self) -> bool:
         """Return whether this instance is derived from wsdl:operation."""
@@ -620,6 +554,17 @@ class Class:
         for inner in self.inner:
             yield from inner.dependencies(allow_circular)
 
+    def has_forward_ref(self) -> bool:
+        """Return whether this class has any forward references."""
+        for attr in self.attrs:
+            if attr.is_forward_ref:
+                return True
+
+            if any(choice for choice in attr.choices if choice.is_forward_ref):
+                return True
+
+        return any(inner.has_forward_ref() for inner in self.inner)
+
 
 @dataclass
 class Import:
