@@ -1,7 +1,7 @@
-from typing import ClassVar
-from typing import Dict
-from typing import List
-from typing import Type
+import subprocess
+from pathlib import Path
+from textwrap import indent
+from typing import ClassVar, Dict, List, Type
 
 from xsdata.codegen.models import Class
 from xsdata.exceptions import CodeGenerationError
@@ -37,7 +37,7 @@ class CodeWriter:
         for result in self.generator.render(classes):
             if result.source.strip():
                 logger.info("Generating package: %s", result.title)
-                src_code = header + result.source
+                src_code = self.ruff_code(header + result.source, result.path)
                 result.path.parent.mkdir(parents=True, exist_ok=True)
                 result.path.write_text(src_code, encoding="utf-8")
 
@@ -45,9 +45,11 @@ class CodeWriter:
         """Iterate over the designated generator outputs and print them to the
         console."""
         self.generator.normalize_packages(classes)
+        header = self.generator.render_header()
         for result in self.generator.render(classes):
             if result.source.strip():
-                print(result.source, end="")
+                src_code = self.ruff_code(header + result.source, result.path)
+                print(src_code, end="")
 
     @classmethod
     def from_config(cls, config: GeneratorConfig) -> "CodeWriter":
@@ -66,3 +68,31 @@ class CodeWriter:
     @classmethod
     def unregister_generator(cls, name: str):
         cls.generators.pop(name)
+
+    def ruff_code(self, src_code: str, file_path: Path) -> str:
+        """Run ruff format on the src code."""
+        commands = [
+            [
+                "ruff",
+                "format",
+                "--stdin-filename",
+                str(file_path),
+                "--line-length",
+                str(self.generator.config.output.max_line_length),
+            ],
+        ]
+        try:
+            src_code_encoded = src_code.encode()
+            for command in commands:
+                result = subprocess.run(
+                    command,
+                    input=src_code_encoded,
+                    capture_output=True,
+                    check=True,
+                )
+                src_code_encoded = result.stdout
+
+            return src_code_encoded.decode()
+        except subprocess.CalledProcessError as e:
+            error = indent(e.stderr.decode(), "  ")
+            raise CodeGenerationError(f"Ruff failed:\n{error}")
