@@ -2,34 +2,23 @@ import re
 import sys
 import textwrap
 from collections import defaultdict
-from typing import Any
-from typing import Callable
-from typing import Dict
-from typing import Iterable
-from typing import List
-from typing import Optional
-from typing import Set
-from typing import Tuple
-from typing import Type
+from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple, Type
 
-from docformatter import configuration
-from docformatter import format
+from docformatter import configuration, format
 from jinja2 import Environment
 
-from xsdata.codegen.models import Attr
-from xsdata.codegen.models import AttrType
-from xsdata.codegen.models import Class
+from xsdata.codegen.models import Attr, AttrType, Class
 from xsdata.formats.converter import converter
 from xsdata.formats.dataclass.models.elements import XmlType
-from xsdata.models.config import DocstringStyle
-from xsdata.models.config import ExtensionType
-from xsdata.models.config import GeneratorConfig
-from xsdata.models.config import GeneratorExtension
-from xsdata.models.config import ObjectType
-from xsdata.models.config import OutputFormat
-from xsdata.utils import collections
-from xsdata.utils import namespaces
-from xsdata.utils import text
+from xsdata.models.config import (
+    DocstringStyle,
+    ExtensionType,
+    GeneratorConfig,
+    GeneratorExtension,
+    ObjectType,
+    OutputFormat,
+)
+from xsdata.utils import collections, namespaces, text
 from xsdata.utils.objects import literal_value
 
 
@@ -142,6 +131,7 @@ class Filters:
                 "clean_docstring": self.clean_docstring,
                 "import_module": self.import_module,
                 "import_class": self.import_class,
+                "post_meta_hook": self.post_meta_hook,
             }
         )
 
@@ -201,7 +191,9 @@ class Filters:
 
     def class_annotations(self, obj: Class, class_name: str) -> List[str]:
         """Return a list of decorator names."""
-        annotations = [self.default_class_annotation]
+        annotations = []
+        if self.default_class_annotation:
+            annotations.append(self.default_class_annotation)
 
         derived = len(obj.extensions) > 0
         for ext in self.extensions[ExtensionType.DECORATOR]:
@@ -316,7 +308,7 @@ class Filters:
         if not slug or not slug[0].isalpha():
             return self.safe_name(f"{prefix}_{name}", prefix, name_case, **kwargs)
 
-        result = name_case(name, **kwargs)
+        result = text.variable(name_case(name, **kwargs))
         if text.is_reserved(result):
             return self.safe_name(f"{name}_{prefix}", prefix, name_case, **kwargs)
 
@@ -346,6 +338,11 @@ class Filters:
 
         return self.class_name(name)
 
+    def post_meta_hook(self, obj: Class) -> Optional[str]:
+        """Plugin hook to render additional information after the xsdata meta
+        class."""
+        return None
+
     def field_metadata(
         self, attr: Attr, parent_namespace: Optional[str], parents: List[str]
     ) -> Dict:
@@ -483,7 +480,9 @@ class Filters:
         length and the additional pad is more than the max line length,
         wrap the text into multiple lines, avoiding breaking long words
         """
-        if data.startswith("Type[") and data.endswith("]"):
+        if (data.startswith("Type[") or data.startswith("type[")) and data.endswith(
+            "]"
+        ):
             return data if data[5] == '"' else data[5:-1]
 
         if data.startswith("Literal[") and data.endswith("]"):
@@ -666,26 +665,14 @@ class Filters:
         if attr.is_prohibited:
             return "Any"
 
-        type_names = collections.unique_sequence(
-            self.field_type_name(x, parents) for x in attr.types
-        )
-
-        if self.union_type:
-            result = " | ".join(type_names)
-        else:
-            result = ", ".join(type_names)
-            if len(type_names) > 1:
-                result = f"Union[{result}]"
-
-        iterable = "Tuple[{}, ...]" if self.format.frozen else "List[{}]"
-        if self.subscriptable_types:
-            iterable = iterable.lower()
+        result = self.field_type_names(attr, parents, choice=False)
 
+        iterable_fmt = self.get_iterable_format()
         if attr.is_tokens:
-            result = iterable.format(result)
+            result = iterable_fmt.format(result)
 
         if attr.is_list:
-            return iterable.format(result)
+            return iterable_fmt.format(result)
 
         if attr.is_tokens:
             return result
@@ -711,30 +698,39 @@ class Filters:
         compound field that might be a list, that's why list restriction
         is also ignored.
         """
-        type_names = collections.unique_sequence(
-            self.field_type_name(x, parents) for x in choice.types
-        )
 
-        if self.union_type:
-            result = " | ".join(type_names)
-        else:
-            result = ", ".join(type_names)
-            if len(type_names) > 1:
-                result = f"Union[{result}]"
+        result = self.field_type_names(choice, parents, choice=True)
 
         if choice.is_tokens:
-            iterable = "Tuple[{}, ...]" if self.format.frozen else "List[{}]"
-            if self.subscriptable_types:
-                iterable = iterable.lower()
-
-            result = iterable.format(result)
+            iterable_fmt = self.get_iterable_format()
+            result = iterable_fmt.format(result)
 
         if self.subscriptable_types:
             return f"type[{result}]"
 
         return f"Type[{result}]"
 
-    def field_type_name(self, attr_type: AttrType, parents: List[str]) -> str:
+    def field_type_names(
+        self, attr: Attr, parents: List[str], choice: bool = False
+    ) -> str:
+        type_names = [
+            self.field_type_name(x, parents, choice=choice) for x in attr.types
+        ]
+        return self.join_type_names(type_names)
+
+    def join_type_names(self, type_names: List[str]) -> str:
+        type_names = collections.unique_sequence(type_names)
+        if len(type_names) == 1:
+            return type_names[0]
+
+        if self.union_type:
+            return " | ".join(type_names)
+
+        return f'Union[{", ".join(type_names)}]'
+
+    def field_type_name(
+        self, attr_type: AttrType, parents: List[str], choice: bool = False
+    ) -> str:
         name = self.type_name(attr_type)
 
         if attr_type.forward and attr_type.circular:
@@ -746,7 +742,7 @@ class Filters:
         elif attr_type.circular:
             name = f'"{name}"'
 
-        if self.postponed_annotations:
+        if self.postponed_annotations and not choice:
             name = name.strip('"')
 
         return name
@@ -764,11 +760,8 @@ class Filters:
 
     def default_imports(self, output: str) -> str:
         """Generate the default imports for the given package output."""
-        result = []
-
-        if self.postponed_annotations:
-            result.append("from __future__ import annotations")
-
+        module_imports = set()
+        func_imports = set()
         for library, types in self.import_patterns.items():
             names = [
                 name
@@ -777,11 +770,19 @@ class Filters:
             ]
 
             if len(names) == 1 and names[0] == "__module__":
-                result.append(f"import {library}")
+                module_imports.add(f"import {library}")
             elif names:
-                result.append(f"from {library} import {', '.join(names)}")
+                func_imports.add(f"from {library} import {', '.join(names)}")
 
-        return "\n".join(sorted(result))
+        imports = sorted(module_imports) + sorted(func_imports)
+        if self.postponed_annotations:
+            imports.insert(0, "from __future__ import annotations")
+
+        return "\n".join(imports)
+
+    def get_iterable_format(self):
+        fmt = "Tuple[{}, ...]" if self.format.frozen else "List[{}]"
+        return fmt.lower() if self.subscriptable_types else fmt
 
     @classmethod
     def build_import_patterns(cls) -> Dict[str, Dict]:
