@@ -1,6 +1,5 @@
 from xsdata.formats.dataclass.parsers.json import JsonParser
 from xsdata.formats.dataclass.parsers.tree import TreeParser
-from xsdata.formats.dataclass.parsers.xml import UserXmlParser
-from xsdata.formats.dataclass.parsers.xml import XmlParser
+from xsdata.formats.dataclass.parsers.xml import UserXmlParser, XmlParser
 
 __all__ = ["JsonParser", "XmlParser", "UserXmlParser", "TreeParser"]
