@@ -1,6 +1,4 @@
-from typing import Dict
-from typing import List
-from typing import Optional
+from typing import Dict, List, Optional
 
 from xsdata.formats.dataclass.parsers.mixins import XmlNode
 
