@@ -1,17 +1,10 @@
-from dataclasses import dataclass
-from dataclasses import field
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Type
+from dataclasses import dataclass, field
+from typing import Dict, List, Optional, Type
 
-from xsdata.formats.dataclass.models.elements import XmlType
-from xsdata.formats.dataclass.models.elements import XmlVar
-from xsdata.formats.dataclass.parsers.bases import NodeParser
-from xsdata.formats.dataclass.parsers.bases import Parsed
+from xsdata.formats.dataclass.models.elements import XmlType, XmlVar
+from xsdata.formats.dataclass.parsers.bases import NodeParser, Parsed
 from xsdata.formats.dataclass.parsers.handlers import default_handler
-from xsdata.formats.dataclass.parsers.mixins import XmlHandler
-from xsdata.formats.dataclass.parsers.mixins import XmlNode
+from xsdata.formats.dataclass.parsers.mixins import XmlHandler, XmlNode
 from xsdata.formats.dataclass.parsers.nodes.wildcard import WildcardNode
 
 
@@ -52,6 +45,7 @@ class TreeParser(NodeParser):
                 format=None,
                 derived=False,
                 any_type=False,
+                process_contents="strict",
                 required=False,
                 nillable=False,
                 sequence=None,
