@@ -1,6 +1,5 @@
 from xsdata.formats.dataclass.serializers.code import PycodeSerializer
-from xsdata.formats.dataclass.serializers.json import DictFactory
-from xsdata.formats.dataclass.serializers.json import JsonSerializer
+from xsdata.formats.dataclass.serializers.json import DictFactory, JsonSerializer
 from xsdata.formats.dataclass.serializers.xml import XmlSerializer
 
 __all__ = [
