@@ -1,21 +1,13 @@
 import re
 import sys
 import warnings
-from dataclasses import dataclass
-from dataclasses import field
+from dataclasses import dataclass, field
 from enum import Enum
 from pathlib import Path
-from typing import Any
-from typing import Callable
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Pattern
-from typing import TextIO
+from typing import Any, Callable, Dict, List, Optional, Pattern, TextIO
 
 from xsdata import __version__
-from xsdata.exceptions import CodeGenerationWarning
-from xsdata.exceptions import GeneratorConfigError
+from xsdata.exceptions import CodeGenerationWarning, GeneratorConfigError
 from xsdata.formats.dataclass.context import XmlContext
 from xsdata.formats.dataclass.parsers import XmlParser
 from xsdata.formats.dataclass.parsers.config import ParserConfig
@@ -24,12 +16,8 @@ from xsdata.formats.dataclass.serializers.config import SerializerConfig
 from xsdata.formats.dataclass.serializers.writers import XmlEventWriter
 from xsdata.logger import logger
 from xsdata.models.enums import Namespace
-from xsdata.models.mixins import array_element
-from xsdata.models.mixins import attribute
-from xsdata.models.mixins import element
-from xsdata.models.mixins import text_node
-from xsdata.utils import objects
-from xsdata.utils import text
+from xsdata.models.mixins import array_element, attribute, element, text_node
+from xsdata.utils import objects, text
 
 
 class StructureStyle(Enum):
@@ -185,17 +173,14 @@ class OutputFormat:
     """
     Output format options.
 
-    :param value: Output format name, default: dataclasses
-    :param repr: Generate __repr__ method, default: true
-    :param eq: Generate __eq__ method, default: true
-    :param order: Generate __lt__, __le__, __gt__, and __ge__ methods,
-        default: false
-    :param unsafe_hash: Generate __hash__ method if not frozen, default:
-        false
-    :param frozen: Enable read only properties, default false
-    :param slots: Enable __slots__, default: false, python>=3.10 Only
-    :param kw_only: Enable keyword only arguments, default: false,
-        python>=3.10 Only
+    :param value: Output format name
+    :param repr: Generate __repr__ method
+    :param eq: Generate __eq__ method
+    :param order: Generate __lt__, __le__, __gt__, and __ge__ methods
+    :param unsafe_hash: Generate __hash__ method if not frozen
+    :param frozen: Enable read only properties
+    :param slots: Enable __slots__, python>=3.10 Only
+    :param kw_only: Enable keyword only arguments, python>=3.10 Only
     """
 
     value: str = text_node(default="dataclasses", cli="output")
@@ -235,18 +220,23 @@ class CompoundFields:
     """
     Compound fields options.
 
-    :param enabled: Use compound fields for repeatable elements,
-        default: false
-    :param default_name: Default compound field name, default: choice
-    :param force_default_name: Always use the default compound field,
-        otherwise if the number of elements is less than 4 the generator
-        will try to dynamically create the field name eg.
+    :param enabled: Use compound fields for repeatable elements
+    :param default_name: Default compound field name
+    :param use_substitution_groups: Use substitution groups if they
+        exist, instead of element names.
+    :param force_default_name: Always use the default compound field
+        name, or try to generate one by the list of element names if
+        they are no longer than the max name parts. e.g.
         hat_or_dress_or_something.
+    :param max_name_parts: Maximum number of element names before using
+        the default name.
     """
 
     enabled: bool = text_node(default=False, cli="compound-fields")
     default_name: str = attribute(default="choice", cli=False)
+    use_substitution_groups: bool = attribute(default=False, cli=False)
     force_default_name: bool = attribute(default=False, cli=False)
+    max_name_parts: int = attribute(default=3, cli=False)
 
 
 @dataclass
@@ -254,24 +244,23 @@ class GeneratorOutput:
     """
     Main generator output options.
 
-    :param package: Target package, default: generated
+    :param package: Target package
     :param format: Output format
-    :param structure_style: Output structure style, default: filenames
-    :param docstring_style: Docstring style, default: reStructuredText
-    :param filter_strategy: Class filter strategy, default: globals
-    :param relative_imports: Use relative imports, default: false
-    :param compound_fields: Use compound fields for repeatable elements,
-        default: false
-    :param max_line_length: Adjust the maximum line length, default: 79
-    :param subscriptable_types: Use PEP-585 generics for standard collections,
-        default: false, python>=3.9 Only
-    :param union_type: Use PEP-604 union type, default: false, python>=3.10 Only
-    :param postponed_annotations: Enable postponed evaluation of annotations,
-        default: false, python>=3.7 Only
-    :param unnest_classes: Move inner classes to upper level, default: false
-    :param ignore_patterns: Ignore pattern restrictions, default: false
-    :param include_header: Include a header with codegen information in the output,
-        default: false
+    :param structure_style: Output structure style
+    :param docstring_style: Docstring style
+    :param filter_strategy: Class filter strategy
+    :param relative_imports: Use relative imports
+    :param compound_fields: Use compound fields for repeatable elements
+    :param max_line_length: Adjust the maximum line length
+    :param subscriptable_types: Use PEP-585 generics for standard
+        collections, python>=3.9 Only
+    :param union_type: Use PEP-604 union type, python>=3.10 Only
+    :param postponed_annotations: Enable postponed evaluation of
+        annotations
+    :param unnest_classes: Move inner classes to upper level
+    :param ignore_patterns: Ignore pattern restrictions
+    :param include_header: Include a header with codegen information in
+        the output
     """
 
     package: str = element(default="generated")
@@ -328,7 +317,7 @@ class NameConvention:
     """
     Name convention model.
 
-    :param case: Naming scheme, eg camelCase, snakeCase
+    :param case: Naming scheme, e.g. camelCase, snakeCase
     :param safe_prefix: A prefix to be prepended into names that match
         one of the reserved words: and, except, lambda, with, as,
         finally, nonlocal, while, assert, false, none, yield, break,
@@ -378,7 +367,7 @@ class GeneratorAlias:
     Each alias has a source attribute that refers to the original name
     in the schema definition and the target attribute for output name.
     For package and module aliases the source refers to the schema
-    filename or target namespace depending the selected output
+    filename or target namespace depending on the selected output
     structure.
 
     :param source: The source name from schema definition
