@@ -1,16 +1,17 @@
 import enum
 import logging
-from dataclasses import fields
-from dataclasses import is_dataclass
-from typing import Any
-from typing import Callable
-from typing import Dict
-from typing import get_type_hints
-from typing import Iterator
-from typing import List
-from typing import Type
-from typing import TypeVar
-from typing import Union
+from dataclasses import fields, is_dataclass
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    Type,
+    TypeVar,
+    Union,
+    get_type_hints,
+)
 
 import click
 from click import Command
@@ -69,6 +70,13 @@ def build_options(obj: Any, parent: str) -> Iterator[Callable[[FC], FC]]:
 
             names.append("__".join(qname.split(".")))
 
+            default_value = (
+                field.default.value
+                if isinstance(field.default, enum.Enum)
+                else field.default
+            )
+            doc_hint += f" [default: {default_value}]"
+
             yield click.option(
                 *names,
                 help=doc_hint,
