@@ -17,7 +17,6 @@ def module_path(module: str) -> Path:
 
 @functools.lru_cache(maxsize=50)
 def module_name(source: str) -> str:
-
     module = source.split("/")[-1]
     name, extension = os.path.splitext(module)
-    return name if extension in (".xsd", ".wsdl", ".xml", ".json") else module
+    return name if extension in (".xsd", ".dtd", ".wsdl", ".xml", ".json") else module
