@@ -1,9 +1,6 @@
 import re
 import string
-from typing import Any
-from typing import List
-from typing import Match
-from typing import Tuple
+from typing import Any, List, Match, Tuple
 
 stop_words = {
     "",
@@ -36,6 +33,7 @@ stop_words = {
     "else",
     "except",
     "field",
+    "Field",
     "finally",
     "float",
     "for",
@@ -225,3 +223,11 @@ def alnum(value: str) -> str:
     """Return a lower case version of the string only with ascii alphanumerical
     characters."""
     return "".join(filter(__alnum_ascii__.__contains__, value)).lower()
+
+
+def variable(value: str) -> str:
+    """Returns a version of the string that will be a valid Python variable."""
+    # Strip out all characters that are not alphanumeric or underscores
+    value = re.sub(r"\W", "", value)
+    # Then strip out leading digit and underscore characters
+    return re.sub(r"^[^a-zA-Z]+", "", value)
